@@ -23,15 +23,21 @@ import java.util.List;
 
 /**
  * Interface for all datatypes that can be found in the database.
+ * Content objects make up a tree and each object can have a parent
+ * and children.  For example, the child of an Image object is a 
+ * Volume or File System.  This interface defines the basic methods for
+ * reading the content associated with this object, the parent and children,
+ * and adding artifacts. 
  */
 public interface Content extends SleuthkitVisitableItem {
 
 	/**
-	 * Read data from the content object
+	 * Reads data that this content object is associated with (file contents, 
+	 * volume contents, etc.).
 	 *
 	 * @param buf a character array of data (in bytes) to copy read data to
-	 * @param offset offset in the content to start reading from
-	 * @param len amount of data to read (in bytes)
+	 * @param offset byte offset in the content to start reading from
+	 * @param len number of bytes to read into buf. 
 	 * @return num of bytes read, or -1 on error
 	 * @throws TskCoreException if critical error occurred during read in the
 	 * tsk core
@@ -46,7 +52,9 @@ public interface Content extends SleuthkitVisitableItem {
 	public void close();
 
 	/**
-	 * Get the size of the content
+	 * Get the (reported) size of the content object and, in theory, how
+	 * much you should be able to read from it.  In some cases, data corruption
+	 * may mean that you cannot read this much data.
 	 *
 	 * @return size of the content
 	 */
@@ -61,7 +69,7 @@ public interface Content extends SleuthkitVisitableItem {
 	public <T> T accept(ContentVisitor<T> v);
 
 	/**
-	 * Get the name of this content object
+	 * Get the name of this content object (does not include parent path)
 	 *
 	 * @return the name
 	 */
@@ -75,7 +83,8 @@ public interface Content extends SleuthkitVisitableItem {
 	public String getUniquePath() throws TskCoreException;
 
 	/**
-	 * Gets the content object id.
+	 * Returns the unique object ID that was assigned to it in the database.
+	 * This is a Sleuth Kit database-assigned number.
 	 *
 	 * @return object id
 	 */
@@ -163,6 +172,16 @@ public interface Content extends SleuthkitVisitableItem {
 	 */
 	public ArrayList<BlackboardArtifact> getArtifacts(String artifactTypeName) throws TskCoreException;
 
+	
+	/**
+	 * Return the TSK_GEN_INFO artifact for the file so that individual attributes 
+	 * can be added to it.
+	 * 
+	 * @returna Instance of the TSK_GEN_INFO artifact
+	 * @throws TskCoreException 
+	 */
+	public BlackboardArtifact getGenInfoArtifact() throws TskCoreException;
+	
 	/**
 	 * Get all artifacts associated with this content that have the given type
 	 * id
