@@ -18,12 +18,12 @@
  */
 
 /* config.h must be first */
-#include "tsk3/tsk_tools_i.h"
+#include "tsk/tsk_tools_i.h"
 #include "fiwalk.h"
 #include "arff.h"
 #include "plugin.h"
 #include "unicode_escape.h"
-#include "tsk3/fs/tsk_fatfs.h"
+#include "tsk/fs/tsk_fatfs.h"
 
 #ifdef _MSC_VER
 #define _CRT_SECURE_NO_WARNINGS
@@ -139,8 +139,8 @@ file_act(TSK_FS_FILE * fs_file, TSK_OFF_T a_off, TSK_DADDR_T addr, char *buf,
     return TSK_WALK_CONT;
 }
 
-/* This is modeled on print_dent_act printit in ./tsk3/fs/fls_lib.c
- * See also tsk_fs_name_print() in ./tsk3/fs/fs_name.c
+/* This is modeled on print_dent_act printit in ./tsk/fs/fls_lib.c
+ * See also tsk_fs_name_print() in ./tsk/fs/fs_name.c
  */
 
 static uint8_t
@@ -178,7 +178,7 @@ process_tsk_file(TSK_FS_FILE * fs_file, const char *path)
                 file_info("inode", fs_file->name->par_addr);
                 if(x) x->pop();
             }
-            if(t||a)
+            if((t||a) && !opt_body_file)
             {
                 file_info("parent_inode", fs_file->name->par_addr);
             }
@@ -216,7 +216,6 @@ process_tsk_file(TSK_FS_FILE * fs_file, const char *path)
 
     /* Finally output the informaton */
     if(opt_body_file && (fs_file->meta != NULL)){
-#ifdef HAVE_TSK_FS_META_MAKE_LS
 	char ls[64];
 	tsk_fs_meta_make_ls(fs_file->meta,ls,sizeof(ls));
 	fprintf(t,"%s|%s|%"PRId64"|%s|%d|%d|%"PRId64"|%d|%d|%d|%d\n",
@@ -228,9 +227,6 @@ process_tsk_file(TSK_FS_FILE * fs_file, const char *path)
 		(uint32_t)fs_file->meta->ctime,
 		(uint32_t)fs_file->meta->crtime);
 	return TSK_WALK_CONT;
-#else
-	err(1,"Cannot make body file without tsk_fs_meta_make_ls. Upgrade your sluthkit.");
-#endif
     }
 
     /* Available information in fs_file:
